<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<!-- 
eXtraWay XML DB - DMS - Record Management and Information Retrieval System

Original code by

Bazzigotti Franco (franco.bazzigotti[at]gmail.com)
Gelli Mauro (gellimauro[at]gmail.com)

Copyright 2005-2012 by 3D Informatica

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Wherever third party code has been used, credit has been given in the code's
comments.

Please contact us for any question at:

3D Informatica
Via Speranza 35 
40068, San Lazzaro di Savena (BOLOGNA)
Italy

Web Site http://www.3di.it

Email to info[at]3di.it

eXtraWay is released under the GPLv2
-->

 <!--

  HXCOORDS language specification
   < HXCOORDS > := < ATOM >{$%< ATOM >}*
   < ATOM > := < POINTS >
             | < OPEN PATH >
             | < CLOSED PATH >
             | < MULTI CLOSED PATH >
   < POINTS > := HxP$2%< precision >$2%< COORDS >
   < OPEN PATH > := HxL$2%< precision >$2%< COORDS >{$%< COORDS >}*
   < CLOSED PATH > := HxA$2%< precision >$2%< COORDS >{$%< COORDS >}*
   < MULTI CLOSED PATH > := HxM$2%< precision >$2%< COORDS >{$%< COORDS >}*{#1%< COORDS >{$%< COORDS >}*}*
   < COORDS > := p0,q0,p1,q1,...,pn-1,qn-1

   da coordItem a number: number=coorditem/pow(10,precision)

  composizione attesa di titolo/@testo
  <HXCOORDS> "$A%" <testo popup> "$A%" <id doc> "$A%1" <id simbolo> "$A%" ...
  "#%n: <id documento> #%t: <testo popup> [#%h: <HXCOORDS>]|[#%x: <x> #%y: <y>] #%s: <id simbolo> #% ..."

  composizione della stringa di definizione del POI:
  "<id documento>#%<testo popup>#%<x>#%<y>#%0#%255#%0#%<swf>[#1%...]"

  composizione della stringa di definizione del PATH:
  "$A%<line color>$A%<fill color>$A%<line alpha>$A%<fill alpha>$A%<line width>$A%<hxc>$A%<testo popup>$A%<id doc>$A%1[$B%...]"

 -->

 <xsl:variable name="poiDataSep" select="'#%'"  /><!-- separatore campi POI -->
 <xsl:variable name="poiSep"     select="'#1%'" /><!-- separatore POI -->
 <xsl:variable name="patDataSep" select="'$A%'" /><!-- separatore campi PATH -->
 <xsl:variable name="patEnd"     select="'$A%1'"/><!-- terminatore PATH -->
 <xsl:variable name="patSep"     select="'$B%'" /><!-- separatore PATH -->
 <xsl:variable name="hxcDataSep" select="'$2%'" /><!-- separatore nella stringa HXCOORDS -->
 <xsl:variable name="inDataSep"  select="'#%'"  /><!-- separatore campi titolo -->

 <!-- nel contesto di un elemento titolo! -->

 <xsl:template name="titleData">
  <xsl:param name="dataId"/>
  <xsl:param name="context" select="."/>
  <xsl:value-of select="normalize-space(substring-before(substring-after($context/@testo,concat($inDataSep,$dataId,':')),concat(' ',$inDataSep)))"/>
 </xsl:template>
 <xsl:template name="hxXCoord"><!-- espressione js per il calcolo della coordinata x di un POI dalla stringa HXCOORDS -->
  <xsl:param name="hxc"/>
  <xsl:variable name="precision" select="substring-before(substring-after($hxc,$hxcDataSep),$hxcDataSep)"/>
  <xsl:value-of select="substring-before(substring-after(substring-after($hxc,$hxcDataSep),$hxcDataSep),',')"/>
  <xsl:text>/Math.pow(10,</xsl:text><xsl:value-of select="$precision"/><xsl:text>)</xsl:text>
 </xsl:template>
 <xsl:template name="hxYCoord"><!-- espressione js per il calcolo della coordinata y di un POI dalla stringa HXCOORDS -->
  <xsl:param name="hxc"/>
  <xsl:variable name="precision" select="substring-before(substring-after($hxc,$hxcDataSep),$hxcDataSep)"/>
  <xsl:variable name="probe" select="substring-before(substring-after($hxc,','),',')"/>
  <xsl:choose>
   <xsl:when test="not($probe='')"><xsl:value-of select="$probe"/></xsl:when>
   <!--
   <xsl:otherwise><xsl:value-of select="substring-before(substring-after($hxc,','),$patDataSep)"/></xsl:otherwise>
   -->
   <xsl:otherwise><xsl:value-of select="substring-after($hxc,',')"/></xsl:otherwise>
  </xsl:choose>
  <xsl:text>/Math.pow(10,</xsl:text><xsl:value-of select="$precision"/><xsl:text>)</xsl:text>
 </xsl:template>
 <!-- parte dei dati notificati da mapworld all'evento click di una geometria -->
 <xsl:template name="docId"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'n'"/></xsl:call-template>
 </xsl:template>
 <!-- geometria nel formato hxc -->
 <xsl:template name="hxCoords"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'h'"/></xsl:call-template>
 </xsl:template>
 <xsl:template name="xCoord"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'x'"/></xsl:call-template>
 </xsl:template>
 <xsl:template name="yCoord"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'y'"/></xsl:call-template>
 </xsl:template>
 <!-- la descrizione presentata da mapworld nel baloon onmouseover -->
 <xsl:template name="text"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'t'"/></xsl:call-template>
 </xsl:template>
 <!-- dati extra gestiti dalla estensione applicativa -->
 <xsl:template name="cData"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'c'"/></xsl:call-template>
 </xsl:template>
 <!-- trattamento idoneo ad un argomento js per la descrizione presentata da mapworld nel baloon onmouseover -->
 <xsl:template name="jText"><xsl:param name="context" select="."/><!-- stringa js racchiusa tra doppi apici -->
  <xsl:variable name="text"><xsl:call-template name="text"><xsl:with-param name="context" select="$context"/></xsl:call-template></xsl:variable>
  <xsl:call-template name="quoteString"><xsl:with-param name="stringa" select="$text"/><xsl:with-param name="occurrent">"</xsl:with-param></xsl:call-template>
 </xsl:template>
 <!-- l'id utilizzato per lo smistamento sui plugin, nel contesto della selezione elementi con stesso id finiscono in un layer comune -->
 <xsl:template name="shapeId"><xsl:param name="context" select="."/>
  <xsl:call-template name="titleData"><xsl:with-param name="context" select="$context"/><xsl:with-param name="dataId" select="'s'"/></xsl:call-template>
 </xsl:template>

</xsl:stylesheet>
