<?xml version="1.0" encoding="iso-8859-1"?>
<!-- 
eXtraWay XML DB - DMS - Record Management and Information Retrieval System

Original code by

Bazzigotti Franco (franco.bazzigotti[at]gmail.com)
Gelli Mauro (gellimauro[at]gmail.com)

Copyright 2005-2012 by 3D Informatica

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Wherever third party code has been used, credit has been given in the code's
comments.

Please contact us for any question at:

3D Informatica
Via Speranza 35 
40068, San Lazzaro di Savena (BOLOGNA)
Italy

Web Site http://www.3di.it

Email to info[at]3di.it

eXtraWay is released under the GPLv2
-->
<!--
	* Created on........: 18/07/2005
	* by................: Federico Grillini
	* organization......: 3D Informatica
	*
	* Questo file deve essere incluso da tutti gli xsl specifici (i primi ad essere caricati) che devono produrre
	* un output di tipo strict xhtml.
	* In questo file, infatti, e' contenuta la dichiarazione del tipo di output e della dtd da usare. Inoltre, 
	* sono presenti dei template pensati per agevolare la scrittura delle pagine xhtml.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* Questo template fa match con la radice "html" del template da trasformare e aggiunge ad essa gli
		* attributi che sono obbligatori in xhtml.<br>
		* Per fare cio' evitando problemi vari legati all'uso dei namespace in xsl, la doctype e la radice
		* vengono scritti nell'output come semplice testo (creando, infatti, un elemento 'html' con il namespace
		* opportuno, negli elementi figli 'head' e 'body' figurano delle dichiarazioni del namespace nullo, cosa
		* non gradita ai validatori).<br><br>
		*
		* NOTA: tale soluzione non funziona quando trasforma Mozilla Firefox, dato che tale browser non supporta
		* 		l'istruzione xsl "disable-output-escaping".
	-->
  <xsl:template match="html" mode="template" priority="100">
  	<xsl:text disable-output-escaping="yes">
  		&lt;!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"&gt;
  		&lt;html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en"&gt;
  	</xsl:text>
  		
  	<xsl:apply-templates select="node()" mode="template" />
  	
  	<xsl:text disable-output-escaping="yes">&lt;/html&gt;</xsl:text>
  </xsl:template>
  
  <!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* Questo template fa match con gli elementi 'form' e inserisce gli attributi necessari se non
		* sono presenti (cioe' 'method' e 'action').<br>
		* Inoltre, elimina l'eventuale attributo 'name' (proibito) sostituendolo con l'attributo 'id'
		* (qualora siano presenti sia 'id' sia 'name', viene mantenuto solo 'id').
		*
  -->
  <xsl:template match="form" mode="template" priority="100">
  	<xsl:param name="blockData" select="$hxpdata"/>
  	
	<xsl:copy>
		<xsl:copy-of select="@*[not(name()='name')]"/> <!-- non ricopio 'name' perche' e' proibito -->
		
		<!-- attributo 'method' -->
		<xsl:if test="not(./@method)">
			<xsl:attribute name="method">
				<xsl:value-of select="post"/>
			</xsl:attribute>
		</xsl:if>
		
		<!-- attributo 'action' -->
		<xsl:if test="not(./@action)">
			<xsl:attribute name="action">
				<xsl:value-of select="$hxpdata/@uri"/>
			</xsl:attribute>
		</xsl:if>
		
		<!-- attributo 'id' -->
		<xsl:if test="./@name and not(./@id)">
			<!-- non e' presente 'id', ma c'e' 'name'=> assegno ad 'id' il suo valore -->
			<xsl:attribute name="id">
				<xsl:value-of select="./@name"/>
			</xsl:attribute>
		</xsl:if>
		
		<!-- attributo 'accept-charset' -->
		<xsl:if test="not(./@accept-charset)">
			<xsl:attribute name="accept-charset">
				<xsl:text>iso-8859-1</xsl:text>
			</xsl:attribute>
		</xsl:if>
		
		<xsl:call-template name="hxpcontinuecontext">
			<xsl:with-param name="blockData" select="$blockData"/>
		</xsl:call-template>
	</xsl:copy>
  </xsl:template>	
  
  <!--
  	Per l'xhtml l'output deve essere necessariamente di tipo xml. Inoltre, 'indent' deve essere "no" per evitare 
  	inutili spazi che potrebbero portare alla generazione di linee troppo lunghe che possono essere troncate con
  	line break dal parser (e cio' puo' creare problemi, per es., nelle chiamate javascript).
  -->
  <xsl:output method="xml" indent="no" encoding="iso-8859-1"/>
</xsl:stylesheet>
