<?xml version="1.0" encoding="iso-8859-1"?>
<!-- 
eXtraWay XML DB - DMS - Record Management and Information Retrieval System

Original code by

Bazzigotti Franco (franco.bazzigotti[at]gmail.com)
Gelli Mauro (gellimauro[at]gmail.com)

Copyright 2005-2012 by 3D Informatica

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Wherever third party code has been used, credit has been given in the code's
comments.

Please contact us for any question at:

3D Informatica
Via Speranza 35 
40068, San Lazzaro di Savena (BOLOGNA)
Italy

Web Site http://www.3di.it

Email to info[at]3di.it

eXtraWay is released under the GPLv2
-->
<!--
	* Created on........: 17/06/2005
	* by................: Federico Grillini
	* organization......: 3D Informatica
	*
	* Questo file contiene dei template per l'elaborazione di stringhe. Inoltre include la libreria 
	* XSLT Standard Library per elaborazioni delle stringhe.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<!-- Federico 29/06/05: libreria XSLT Standard Library per elaborazioni delle stringhe -->
	<xsl:include href="xsltsl-1.2.1/string.xsl"/>
	
	<!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* @param string 		stringa in cui cercare il carattere 'char'.
		* @param char 			carattere di cui si vuole cercare l'ultima occorrenza.
		* @param originalString	questo e' un parametro per uso interno che, quindi, non deve essere
		*						mai utilizzato. Esso consente di fare un backup della stringa originale
		*						'string', dato che, ad ogni iterazione, 'string' viene modificata.
		*
		* Questo template realizza la funzione lastIndexOf, che cerca l'ultima occorrenza di 'char'
		* presente nella stringa 'string'.<br>
		* Il template restituisce la posizione dell'ultimo carattere 'char' o un numero negativo qualora
		* 'char' non sia presente.
	-->
	<xsl:template name="lastIndexOf">
     <xsl:param name="string"/>						<!-- stringa da esaminare -->
     <xsl:param name="char"/>						<!-- carattere da cercare -->
     <xsl:param name="originalString" select="''"/>	<!-- backup della stringa originale -->
     
	 <xsl:variable name="newOriginalString">
	     <xsl:choose>
		     <xsl:when test="$originalString=''">
		     	<!-- prima chiamata al template: backup della stringa originale -->
				<xsl:value-of select="$string"/>
		     </xsl:when>
		     <xsl:otherwise>
		     	<!-- chiamate successive alla prima: trasmissione di '$originalString' -->
		     	<xsl:value-of select="$originalString"/>
		     </xsl:otherwise>
	     </xsl:choose>
	 </xsl:variable>
     
     <xsl:choose>
        <xsl:when test="contains($string, $char)">
           <!-- ricorsione... -->
           <xsl:call-template name="lastIndexOf">
              <xsl:with-param name="string" select="substring-after($string, $char)" />
              <xsl:with-param name="char" select="$char" />
              <xsl:with-param name="originalString" select="$newOriginalString" />
           </xsl:call-template>
        </xsl:when>
        <!-- restituisco la posizione dell'ultimo carattere 'char' o un numero negativo qualora 'char' non sia presente -->
        <xsl:otherwise>
        	<xsl:value-of select="string-length($originalString) - string-length($string)"/>
        </xsl:otherwise>
     </xsl:choose>
  </xsl:template>
  
  <!-- introdotto da mbussetti il 18/03/2005
	   Template recursivo che estrae l'ultima porzione di una stringa, dove le parti sono delimitate da un separatore
  -->
  <xsl:template name="splitLast">
	<xsl:param name="salsiccia" select="''" />
	<xsl:param name="nodino" select="''" />
	<xsl:choose>
		<xsl:when test="contains($salsiccia,$nodino)">
			<xsl:call-template name="splitLast">
				<xsl:with-param name="salsiccia" select="substring-after($salsiccia,$nodino)" />
				<xsl:with-param name="nodino" select="$nodino" />
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$salsiccia"/>
		</xsl:otherwise>
	</xsl:choose>
  </xsl:template>
  
  <!--
  	* @author Federico Grillini
	*
	* @version 1.0
	*
	* @param strvalue stringa da controllare.
	*
	* Questo template verifica se la stringa passata come parametro e' un numero (sono consentiti anche
	* valori numerici con decimali, con separatori ',' o '.').<br>
	* Se 'strvalue' e' un numero viene restituto 'true'; altrimenti viene restituto 'false'.
  -->
  <xsl:template name="isNumber">
		<xsl:param name="strvalue" select="''"/>
		
		<!-- controllo se 'strvalue' e' non vuota e contiene un numero (anche con ',' o '.') -->
		<xsl:choose>
			<xsl:when test="$strvalue!='' and string-length(translate($strvalue,'0123456789,.',''))=0">
				<xsl:value-of select="'true'"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- 'strvalue' e' vuota o non e' un numero -->
				<xsl:value-of select="'false'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* @param s stringa da controllare.
		*
		* Questo template elimina i whitespace presenti all'inizio della stringa 's'.
	-->
	<xsl:template name="left-trim">
	  <xsl:param name="s"/>
	
	  <xsl:choose>
	  	<xsl:when test="string-length($s) = 1">
	  		<xsl:value-of select="normalize-space($s)"/>
	  	</xsl:when>
	  	<xsl:when test="string-length($s) &gt; 1">
		  <xsl:choose>
		    <xsl:when test="normalize-space(substring($s, 1, 1)) = ''">
		      <xsl:call-template name="left-trim">
		        <xsl:with-param name="s" select="substring($s, 2)"/>
		      </xsl:call-template>
		    </xsl:when>
		    <xsl:otherwise>
		      <xsl:value-of select="$s"/>
		    </xsl:otherwise>
		  </xsl:choose>
		</xsl:when>
	  </xsl:choose>
	</xsl:template>

	<!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* @param s stringa da controllare.
		*
		* Questo template elimina i whitespace presenti alla fine della stringa 's'.
	-->
	<xsl:template name="right-trim">
	  <xsl:param name="s"/>
	
	  <xsl:choose>
	  	<xsl:when test="string-length($s) = 1">
	  		<xsl:value-of select="normalize-space($s)"/>
	  	</xsl:when>
	  	<xsl:when test="string-length($s) &gt; 1">
		  <xsl:choose>
		    <xsl:when test="normalize-space(substring($s, string-length($s))) = ''">
		      <xsl:call-template name="right-trim">
		        <xsl:with-param name="s" select="substring($s, 1, string-length($s) - 1)"/>
		      </xsl:call-template>
		    </xsl:when>
		    <xsl:otherwise>
		      <xsl:value-of select="$s"/>
		    </xsl:otherwise>
		  </xsl:choose>
		</xsl:when>
	  </xsl:choose>  
	</xsl:template>
	
	<!--
		* @author Federico Grillini
		*
		* @version 1.0
		*
		* @param s stringa da controllare.
		*
		* Questo template elimina i whitespace presenti all'inizio e alla fine della stringa 's'.
	-->
	<xsl:template name="trim">
	  <xsl:param name="s"/>
	
	  <xsl:variable name="left-trimmed-str">
	  	<xsl:call-template name="left-trim">
	    	<xsl:with-param name="s" select="$s"/>
	    </xsl:call-template>
	  </xsl:variable>
	  
	  <xsl:call-template name="right-trim">
	  	<xsl:with-param name="s" select="$left-trimmed-str"/>
	  </xsl:call-template>
	</xsl:template>
</xsl:stylesheet>
	