/*
eXtraWay XML DB - DMS - Record Management and Information Retrieval System

Original code by

Bazzigotti Franco (franco.bazzigotti[at]gmail.com)
Gelli Mauro (gellimauro[at]gmail.com)

Copyright 2005-2012 by 3D Informatica

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Wherever third party code has been used, credit has been given in the code's
comments.

Please contact us for any question at:

3D Informatica
Via Speranza 35 
40068, San Lazzaro di Savena (BOLOGNA)
Italy

Web Site http://www.3di.it

Email to info[at]3di.it

eXtraWay is released under the GPLv2
*/
// Data: 10/05/2000
// Scopo: Funzioni di utilita'

// Elimina gli spazi prima e dopo in una stringa
function trim(str) {
	if (!str)
		return str;
	while (str.length && (str.substring(0, 1) == " " || str.substring(0, 1) == "\t"))
		str = str.substring(1, str.length);
	while (str.length && (str.substring(str.length - 1, str.length) == " " || str.substring(str.length - 1, str.length) == "\t"))
		str = str.substring(0, str.length - 1);
	return str;
}

// Verifica se un carattere e' numerico
function IsDigit(chr) {
	if (chr < '0' || chr > '9')
		return false;
	else
		return true;
}

function ValidElement(stringa, begin, end) {
	var val;

	for (val = ""; begin <= end; begin++) {
		if (!IsDigit(stringa.charAt(begin)))
			return false;
		val += stringa.charAt(begin);
	}
	return val;
}

// Controlla la validita' di una stringa contenente una data
// Ritorna:	0 OK
//			1 'Data non nel formato gg/mm/aaaa'
//			2 'Giorno non compreso tra 01 e 31'
//			3 'Mese non compreso tra 01 e 12'
//			4 'Anno non superiore a 0000'
//			28 'Il giorno dovrebbe essere compreso tra 01 e 28'
//			29 'Il giorno dovrebbe essere compreso tra 01 e 29'
//			30 'Il giorno dovrebbe essere compreso tra 01 e 30'
//			31 'Il giorno dovrebbe essere compreso tra 01 e 31'
function ChkDate(str) {
	var day, month, year;
	var MaxDay;

	if (str.length != 10) return 1;

	day = ValidElement(str, 0, 1);
	month = ValidElement(str, 3, 4);
	year = ValidElement(str, 6, 9);
	
	if (day == 0 || month == 0 || year == 0 || str.charAt(2) != '/' || str.charAt(5) != '/') return 1;
	if (day <= 0) return 2;
	if (month < 1 || month > 12) return 3;
	if (year < 1) return 4;
	if (month == 11 || month == 4 || month == 6 || month == 9)
		MaxDay = 30;
	else if (month == 2) {
		MaxDay = 28;
		if (year % 400 == 0 || ((year % 4) == 0 && (year % 100) != 0))
			MaxDay++;
	}
	else
		MaxDay = 31;
	if (day > MaxDay) return MaxDay;

	return 0;
}

// Controlla la validita' di una stringa contenente un'ora
// Ritorna:	0 OK
//			1 'Ora non nel formato hh:mm'
//			2 'Ora non compresa tra 00 e 23'
//			3 'Minuto non compreso tra 00 e 59'
function ChkTime(str) {
	var hour, minute;

	if (str.length != 5) return 1;

	if (!IsDigit(str.charAt(0)))
		return 1;
	if (!IsDigit(str.charAt(1)))
		return 1;
	hour = ValidElement(str, 0, 1);
	if (!IsDigit(str.charAt(3)))
		return 1;
	if (!IsDigit(str.charAt(4)))
		return 1;
	minute = ValidElement(str, 3, 4);
	
	if (str.charAt(2) != ':') return 1;
	if (hour > 23) return 2;
	if (minute > 59) return 3;

	return 0;
}

//Verifica se una stringa e' un numero
function IsNumber(str) {
	var chr;
	str = trim(str);
	for (var i = 0; i < str.length; ++i) {
		chr = str.charAt(i);
		if (chr == "-" || chr == "+") {
			if (i != 0) return false;
		}
		else {
			if (!IsDigit(chr)) return false;
		}
	}
	return true;
}

//Converte una data da "gg/mm/aaaa" a "aaaammgg"
function ConvertDate(str) {
	return str.substr(6, 4) + str.substr(3, 2) + str.substr(0, 2);
}