#!/usr/bin/env bash
#
# Xwctl utility script: 0.0.6.0
#

#eXtraWay XML DB - DMS - Record Management and Information Retrieval System
#Original code by
#
#Bazzigotti Franco (franco.bazzigotti[at]gmail.com)
#Gelli Mauro (gellimauro[at]gmail.com)
#
#Copyright 2005-2012 by 3D Informatica
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#Wherever third party code has been used, credit has been given in the code's
#comments.
#
#Please contact us for any question at:
#
#3D Informatica
#Via Speranza 35 
#40068, San Lazzaro di Savena (BOLOGNA)
#Italy
#
#Web Site http://www.3di.it
#
#Email to info[at]3di.it
#
#eXtraWay is released under the GPLv2


#UTILITY Section

# Function to check listening socket ports 
listener() {

  case `uname -s` in
    Linux)
      netstat -nlut | grep "$1" >/dev/null 2>&1
      if [ $? -eq 0 ] ; then
        echo -n "listen on port $1"
      else
        return 1
      fi
      ;;
    *)
      return 0
      ;;
  esac
}

#Return function on execution of 'start' or 'status' command
getErrCode()
 {
   if [ "xstatus" = "x$1" ]; then
     # status: "program or service status is unknown"
     ret='4'
   else
     # non status: "generic or unspecified error"
     ret='1'
   fi

   echo $ret
 }

#Function that translates the return signal execting a 'stop' command
getStopCode()
 {
   if [ "3" = "$1" ]; then
     # "ok"
     ret='0'
   elif [ $1 -eq 1 ]; then
     # "generic or unspecified error"
     ret=0
   else
      ret=$1
   fi

   echo $ret
 }




#START Section

Xstart() {
  ret='0'
  fail="--- eXtraWay start failure:"
  ldpath=$xw_ldpath
  nicelev=$xw_nicelevel


  # 'log' rotation
  if [ '0' = $ret ] && [ 1024 -lt `du -k $xw_home/$xwctl_log | cut -f1` ] ; then
    rm $xw_home/$xwctl_log.4.gz
    mv $xw_home/$xwctl_log.3.gz $xw_home/$xwctl_log.4.gz
    mv $xw_home/$xwctl_log.2.gz $xw_home/$xwctl_log.3.gz
    mv $xw_home/$xwctl_log.1.gz $xw_home/$xwctl_log.2.gz
    mv $xw_home/$xwctl_log $xwctl_log.1
    gzip -N9 $xw_home/$xwctl_log.1 &
  fi


  if [ -n "$ldpath" ] ; then
    LD_LIBRARY_PATH=$ldpath
    DYLD_LIBRARY_PATH=$ldpath
    export LD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
  fi


  if [ '0' = $ret ] && [ ! -x $xw_home/xw ] ; then
    echo  $fail "'xw' module missing" >> $xw_home/$xwctl_log
    ret='3'
  fi

  if [ '0' = $ret ] ; then
    if [ $whoAmI == $xw_user ]; then
      nice -n $nicelev $xw_home/xw -p $xw_port # > /dev/null
    elif [ $whoAmI == "root" ]; then
      su - $xw_user -c "nice -n $nicelev $xw_home/xw -p $xw_port"
    else
      echo " you must be a root or $xw_user user to use this command"
      exit 256
    fi
    if [ $? != $ret ]; then
      echo  $fail "failure starting xw" >> $xw_home/$xwctl_log
      ret='1'
    fi
  fi

  if [ '0' = $ret ] ; then
    echo  "--- eXtraWay services started" >> $xw_home/$xwctl_log
  fi

  return $ret 
}

##VERSION Section
_getVerSed()
 {
   if [ -x /usr/xpg4/bin/sed ] ; then
     sedCmd=/usr/xpg4/bin/sed
   else
     sedCmd=sed
   fi

   toEcho="1"
   prog=`echo $1 | $sedCmd 's/.*\/\(.*\)/\1/'`
   base="Version of '`echo $prog | $sedCmd s/\.so$//`':"
   len=`echo $base | wc -c`
   add=`echo "                                   " | cut -c$len-25`

   if [ -x $1 ] ; then
     verStr=`  cat -v $1 | grep eXtraWay_Version\
             | grep eXtraWay_Version \
             | $sedCmd 's/.*\$Id: eXtraWay_Version \([^\$]*\) \$.*/vErSiOn: \1/'\
             | grep vErSiOn`
     if [ -z "$verStr" ] ; then
       verStr="<version number unavailable>"
     else
       verStr=`echo $verStr | $sedCmd 's/vErSiOn: \(.*\)/\1/'`
       verStr=`echo $verStr | $sedCmd 's/\,/./g'`
     fi
   elif [ "x0" = "x$2" ] ; then
     toEcho="0"
   else
     verStr="<file unavailable>"
   fi

   if [ "x1" = "x$toEcho" ] ; then
     echo "$base $add $verStr"
   fi
 }

home=$xw_home
logf=$xwctl_log

 
Version(){
if [ '0' = $ret ] ; then
  # The following list cause the output of version ID for each module.
  # Second parameter of the list is '1' if a line must be printed even if the module isn't present
  # with a "<file unavailable>" label.
  # If '0', a line is printed only if the module is present.
  echo
  _getVerSed $home/xw             1
  _getVerSed $home/xwls           1
  _getVerSed $home/libxwwd.so     1
  _getVerSed $home/xwctl          1
  echo
fi

return $ret
}



#PIDLIST Section


Xpid() {
  prg=''
  ret='0'
  fail="--- eXtraWay status failure:"
  home=$xw_home

  if [ 1 -le $# ] ; then
     prg=$1
  else
     ret='1'
  fi

  case `uname -s` in
    AIX)
      n=
      c="\c" # help vim sintax --> "
      pXw=`ps ax | grep $xw_port | grep -- $home/xw | grep -v grep | grep -v xw_\
           | grep -v xwctl | grep -v xwls | grep -v xwgl\
           | grep -v $0 | cut -c1-6 | sort -rn`
      pXwls=`ps ax | grep -- $home/xwls | grep -v /xw/ | grep -v grep\
             | grep -v $0 | cut -c1-6 | sort -rn`
    ;;
    Darwin)
      n=-n
      c=""
      pXw=`ps ax  | grep $xw_port | grep -- $home/xw | grep -v grep | grep -v xw_\
           | grep -v xwctl | grep -v xwls | grep -v xwgl | grep -v $0\
           | cut -c1-6 | sort -rn`
      pXwls=`ps ax | grep -- $home/xwls | grep -v grep | grep -v $0\
            | cut -c1-6 | sort -rn`
    ;;
    Linux)
      n=-n
      c=""
      pXw=`ps ax | grep $xw_port | grep -- $home/xw | grep -v grep | grep -v xw_\
           | grep -v xwctl | grep -v xwls | grep -v xwgl | grep -v $0\
           | cut -c1-5 | sort -rn`
      pXwls=`ps ax | grep -- $home/xwls | grep -v grep | grep -v $0\
            | cut -c1-5 | sort -rn`
    ;;
    SCO_SV)
      n=-n
      c=""
      pXw=`ps -ef -o pid -o args | grep $xw_port | grep -- $home/xw | grep -v grep\
           | grep -v xw_ | grep -v xwctl | grep -v xwls | grep -x xwgl\
           | grep -v $0 | cut -c1-6 | sort -rn`
      pXwls=`ps -ef -o pid -o args | grep -- $home/xwls | grep -v grep\
             | grep -v $0 | cut -c1-6 | sort -rn`
    ;;
    SunOS)
      n=
      c="\c" # help vim sintax --> "
      pXw=`ps -ef -o pid -o args | grep $xw_port | grep -- $home/xw | grep -v grep\
           | grep -v xw_ | grep -v xwctl | grep -v xwls | grep -v xwgl\
           | grep -v xw_ | grep -v $0 | cut -c1-6 | sort -rn`
      pXwls=`ps -ef -o pid -o args | grep -- $home/xwls | grep -v grep\
             | grep -v $0 | grep -v xw_ | cut -c1-6 | sort -rn`
    ;;
    UnixWare)
      n=-n
      c=""
      pXw=`ps -ef -o pid -o args | grep $xw_port | grep -- $home/xw | grep -v grep\
           | grep -v xw_ | grep -v xwctl | grep -v xwls | grep -v xwgl\
           | grep -v $0 | cut -c1-6 | sort -rn`
      pXwls=`ps -ef -o pid -o args | grep $xwls_port | grep -- $home/xwls | grep -v grep\
             | grep -v $0 | cut -c1-6 | sort -rn`
    ;;
    *)
      echo  $fail "unknown OS"
      ret='1' 
    ;;
  esac


  if [ '0' = $ret ] ; then
    if [ 'xw' = $prg ] ; then
       echo $n "$pXw"$c
    fi
    if [ 'xwls' = $prg ] ; then
       echo $n "$pXwls"$c
    fi
  fi

  return $ret
}

PKill(){
home=$xw_home
repeat=10

if [ -n "$home" ] ; then
   processes=`Xpid $1`

   if [ "$2" = "soft" ] ; then
     kill_opt=""
   elif [ "$2" = "coredump" ] ; then
     kill_opt="-ABRT"
   else
     kill_opt="-9"
   fi

   while [ -n "${processes}" ] && [ $(( repeat-- )) -gt 0 ]; do
      for pid in $processes ; do
         kill $kill_opt $pid 1>/dev/null 2>&1 || echo "-Error killing $1 - $pid! Wrong user? Already dead?- "
      done
      sleep 1
      processes=`Xpid $1`
   done
   if [ -z "${processes}" ]; then
      return 0
   else
      echo "-Kill method \"$2\" of $1 failed! Trying next step..- "
      return 1
   fi
else
   echo "-\$xw_home undefined, processes not killed!- "
   exit 1 # If no value is properly defined, don't do anything and exit
fi
}

#STOP Section

XstopAll () {
  ret='0'
  fail="--- eXtraWay stop failure:"


  if [ '0' = $ret ] ; then
    if [ -x $xw_home/hwadmin ] ; then
      $xw_home/hwadmin stop_now -p$xw_port           >> $xw_home/$xwctl_log
      if [ $? -ne 0 ] ; then
        echo  $fail "-hwadmin failure- "    >> $xw_home/$xwctl_log
      fi
      sleep 2
    fi
    if [ -n "Xpid xw" ] ; then
       PKill xw soft             >> $xw_home/$xwctl_log || \
       PKill xw hard             >> $xw_home/$xwctl_log || \
       echo "-Failed to stop xw- "  >> $xw_home/$xwctl_log
    fi

    if [ -x $xw_home/xwls ] ; then
       $xw_home/xwls -stop                       >> $xw_home/$xwctl_log
       sleep 1
       if [ -n "Xpid xwls" ] ; then
          PKill xwls soft            >> $xw_home/$xwctl_log ||
          PKill xwls hard            >> $xw_home/$xwctl_log ||
          echo "-Failed to stop xwls- "  >> $xw_home/$xwctl_log
       fi
    fi

    echo  "--- eXtraWay services stopped" >> $xw_home/$xwctl_log
  fi

  return $ret
}

#Master Server status function
Statum() {
  
      xwPid=`Xpid xw` 
      xwlsPid=`Xpid xwls` 
      #xw pids
      MustM=0
      echo -n "xw: "
      listener $xw_port
      echo -n " PIDS:"
      if [ -r $PIDFILE ]; then
          Master=`cat $PIDFILE`
        for pids in $xwPid; do
          if [[ $Master != $pids ]]
            then
              echo -n " ($pids)"
            else
              echo -n " [$Master]"
              MustM=1
              ret=0
          fi
        done
        echo ""
        if [ $MustM -eq 0 ]
          then
          echo " [Master not found!]"
          ret=1
        fi
      else
        if [[ -n $xwPid ]]; then
        for pid in $xwPid; do
              echo -n " $pid"
        done
          echo " no such file: $PIDFILE"
        fi
          ret=1
      fi ;


#xwls pids

      if [[ -n $xwlsPid ]];then
        echo -n "xwls: " 
        listener  $xwls_port 
        echo " PID: $xwlsPid " 
      else
       echo "xwls [Not found]"
      fi

return $ret
echo "statum $ret"
}

